@@ -406,8 +406,8 @@ props_init_main(GHashTable * config_rc)
 {
 	/* if there is no config version set, assume it is a config file from a version before the config version was introduced
 	this was introduced in revision r7372 in april 2012, which was released in june 2012 in the 2.2.3 release */
-	init_prop_string(&config_rc, &main_v->props.config_version, "config_version:", "2.2.2");
-	init_prop_integer(&config_rc, &main_v->props.do_periodic_check, "do_periodic_check:", 1, TRUE);
+	init_prop_string(&config_rc, &main_v->props.config_version, "config_version:", "2.2.7");
+	init_prop_integer(&config_rc, &main_v->props.check_for_modified_on_disk, "check_for_modified_on_disk:", 1, TRUE);
 #ifdef MAC_INTEGRATION
 	init_prop_string(&config_rc, &main_v->props.editor_font_string, "editor_font_string:", "Lucida Grande 13");
 #else
@@ -542,34 +542,34 @@ merge_config_files(GFile * oldrc, GFile * oldsession, GFile * newrc, GFile * new
 
 	istream = (GInputStream *) g_file_read(oldrc, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while reading old file %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		return FALSE;
 	}
 	ostream = (GOutputStream *) g_file_append_to(newrc, G_FILE_CREATE_PRIVATE, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while appending %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		g_input_stream_close(istream, NULL, &gerror);
 		return FALSE;
 	}
 	g_output_stream_splice(ostream, istream, G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while splicing %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		g_output_stream_close(ostream, NULL, &gerror);
 		return FALSE;
 	}
 	istream = (GInputStream *) g_file_read(oldsession, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while reading session file %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		g_output_stream_close(ostream, NULL, &gerror);
 		return FALSE;
 	}
 	g_output_stream_splice(ostream, istream, G_OUTPUT_STREAM_SPLICE_CLOSE_SOURCE, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while splicing session file %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		g_output_stream_close(ostream, NULL, &gerror);
 		return FALSE;
@@ -577,27 +577,31 @@ merge_config_files(GFile * oldrc, GFile * oldsession, GFile * newrc, GFile * new
 	g_output_stream_close(ostream, NULL, &gerror);
 	g_file_copy(newrc, newsession, G_FILE_COPY_BACKUP, NULL, NULL, NULL, &gerror);
 	if (gerror) {
-		g_print("config file migration error %d:%s", gerror->code, gerror->message);
+		g_print("config file migration error while copying %d:%s\n", gerror->code, gerror->message);
 		g_error_free(gerror);
 		return FALSE;
 	}
 	return TRUE;
 }
 
-static void
+static gboolean
 migrate_config_files(GHashTable * main_configlist, GFile * newrc)
 {
 	GFile *oldrc, *oldsession, *newsession;
 	oldrc = user_bfdir(OLDCONFIG);
 	oldsession = user_bfdir(OLDSESSION);
 	newsession = user_bfdir(CURSESSION);
-	merge_config_files(oldrc, oldsession, newrc, newsession);
+	if (merge_config_files(oldrc, oldsession, newrc, newsession)) {
 	/* add some entries to main_configlist. because main_configlist is used for
 	   saving as well this means we'll save these entries too */
-	if (parse_config_file(main_configlist, newrc)) {
-		/* are there any entries that we want to convert ?? */
-		save_config_file(main_configlist, newrc);
+		if (parse_config_file(main_configlist, newrc)) {
+			/* are there any entries that we want to convert ?? */
+			save_config_file(main_configlist, newrc);
+			return TRUE;
+		}
+		return FALSE;
 	}
+	return FALSE;
 }
 
 
@@ -783,14 +787,14 @@ GList *update_filters(GList *current, gboolean overwrite)
 					  array_from_arglist(_("Javascript Minify with jsmin"), "|python "PKGDATADIR"/jsmin.py|", NULL));
 	defaults =
 		g_list_append(defaults,
-					  array_from_arglist(_("CSS Minify with cssmin"), "|python "PKGDATADIR"/cssmin.py|", NULL));
+					  array_from_arglist(_("Toggle CSS compression"), "|python "PKGDATADIR"/css_decompressor|", NULL));
 #else
 	defaults =
 		g_list_append(defaults,
 					  array_from_arglist(_("Javascript Minify with jsmin"), "|"PKGDATADIR"/jsmin.py|", NULL));
 	defaults =
 		g_list_append(defaults,
-					  array_from_arglist(_("CSS Minify with cssmin"), "|"PKGDATADIR"/cssmin.py|", NULL));
+					  array_from_arglist(_("Toggle CSS compression"), "|"PKGDATADIR"/css_decompressor|", NULL));
 #endif
 	defaults =
 		g_list_append(defaults,
@@ -804,24 +808,6 @@ GList *update_commands(GList *current, gboolean overwrite)
 {
 	GList *defaults=NULL, *retlist;
 #ifdef WIN32
-	defaults =
-		g_list_prepend(defaults,
-					  array_from_arglist(_("Windows XP Firefox"),
-										 "\"C:\\Program Files\\Mozilla Firefox\\firefox.exe\" '%p'",
-										 "1", NULL));
-	defaults =
-		g_list_prepend(defaults,
-					  array_from_arglist(_("Windows XP Internet Explorer"),
-										 "\"C:\\Program Files\\Internet Explorer\\iexplore.exe\" '%p'",
-										 "0", NULL));
-	defaults =
-		g_list_prepend(defaults,
-					  array_from_arglist(_("Windows XP Opera"),
-										 "\"C:\\Program Files\\Opera\\opera.exe\" '%p'", "0", NULL));
-	defaults =
-		g_list_prepend(defaults,
-					  array_from_arglist(_("Windows XP Safari"),
-										 "\"C:\\Program Files\\Safari\\safari.exe\" '%p'", "0", NULL));
 	defaults =
 		g_list_prepend(defaults,
 					  array_from_arglist(_("Windows 7 Firefox 32-bit"),
@@ -859,8 +845,7 @@ GList *update_commands(GList *current, gboolean overwrite)
 #else
 	defaults =
 		g_list_prepend(defaults,
-					  array_from_arglist(_("Firefox"), "firefox -remote 'openURL(%p)' || firefox '%p'&",
-										 "1", NULL));
+					  array_from_arglist(_("Firefox"), "firefox '%p'&", "1", NULL));
 	defaults =
 		g_list_prepend(defaults,
 					  array_from_arglist(_("Opera"), "opera -remote 'openURL(%p)' || opera '%p'&", "0",
@@ -908,7 +893,10 @@ rcfile_parse_main(void)
 		g_warning("no configfile %s, try to convert config files from older versions\n", CURCONFIG);
 		/* probably there is no configfile. try to migrate the configfile from a previous
 		   version */
-		migrate_config_files(main_configlist, file);
+		if (!migrate_config_files(main_configlist, file)) {
+			g_free(main_v->props.config_version);
+			main_v->props.config_version = NULL; 	/* We do not have any config file */	
+		}
 	}
 	g_object_unref(file);
 	if (main_v->props.encoding_search_Nbytes < 1000)
@@ -916,8 +904,10 @@ rcfile_parse_main(void)
 
 	/* do some default configuration for the lists */
 	DEBUG_MSG("config_version=%s\n",main_v->props.config_version);
-	if (!main_v->props.config_version || strlen(main_v->props.config_version)<5 ||main_v->props.config_version[0] < '2' || main_v->props.config_version[2] < '2' || main_v->props.config_version[4] < '4') {
-		main_v->props.rcfile_from_old_version = 1;
+	if (main_v->props.config_version && (strlen(main_v->props.config_version)<5 ||main_v->props.config_version[0] < '2' || main_v->props.config_version[2] < '2' || main_v->props.config_version[4] < '4')) {
+		main_v->props.rcfile_from_old_version = 1; /* We got old version after migration */
+	}
+	if (!main_v->props.config_version || (main_v->props.rcfile_from_old_version == 1)) {
 		main_v->props.external_command = update_commands(main_v->props.external_command, FALSE);
 		main_v->props.external_filter = update_filters(main_v->props.external_filter, FALSE);
 		main_v->props.external_outputbox = update_outputbox(main_v->props.external_outputbox, FALSE);
@@ -1204,6 +1194,7 @@ return_session_configlist(GHashTable * configlist, Tsessionvars * session)
 	init_prop_integer(&configlist, &session->ssearch_unescape, "ssearch_unescape:", 0, FALSE);
 	init_prop_integer(&configlist, &session->ssearch_casesens, "ssearch_casesens:", 0, FALSE);
 	init_prop_string_with_escape(&configlist, &session->snr3_filepattern, "snr_filepattern:", NULL);
+	init_prop_string_with_escape(&configlist, &session->snr3_basedir, "snr_basedir:", NULL);
 	init_prop_string_with_escape(&configlist, &session->ssearch_text, "ssearch_text:", NULL);
 
 	init_prop_integer(&configlist, &session->display_right_margin, "display_right_margin:", 0, FALSE);
@@ -1514,3 +1505,37 @@ load_templates(void)
 	g_object_unref(uri);
 	main_v->templates = g_list_concat(t1, t2);
 }
+
+#ifdef MEMORY_LEAK_DEBUG
+void props_free()
+{
+	gint i;
+	g_free(main_v->props.config_version);
+	g_free(main_v->props.editor_font_string);
+	g_free(main_v->props.tab_font_string);
+	g_free(main_v->props.tab_color_modified);
+	g_free(main_v->props.tab_color_loading);
+	g_free(main_v->props.tab_color_error);
+	free_arraylist(external_command);
+	free_arraylist(external_filter);
+	free_arraylist(external_outputbox);
+	g_free(main_v->props.image_thumbnailstring);
+	g_free(main_v->props.image_thumbnailtype);
+	g_free(main_v->props.newfile_default_encoding);
+	g_free(main_v->props.project_suffix);
+	free_arraylist(plugin_config);
+	for (i=0;i<BTV_COLOR_COUNT;i++) {
+		g_free(btv_color_str[i]);
+	}
+	free_arraylist(textstyles);
+	free_arraylist(highlight_styles);
+	free_arraylist(bflang_options);
+#ifdef WIN32
+	free_arraylist(file_association);
+#endif
+	g_free(main_v->props.autocomp_accel_string);
+	g_free(main_v->props.autosave_file_prefix);
+	g_free(main_v->props.autosave_file_suffix);
+	g_free(main_v->props.language);
+}
+#endif
